@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace libphonenumber\Tests\timezone;
 
 use libphonenumber\PhoneNumber;
@@ -19,14 +21,8 @@ class PrefixTimeZonesMapTest extends TestCase
     public const MOSCOW_TZ = 'Europe/Moscow';
     public const VLADIVOSTOK_TZ = 'Asia/Vladivostok';
     public const YEKATERINBURG_TZ = 'Asia/Yekaterinburg';
-    /**
-     * @var PrefixTimeZonesMap
-     */
-    private static $prefixTimeZonesMapForUS;
-    /**
-     * @var PrefixTimeZonesMap
-     */
-    private static $prefixTimeZonesMapForRU;
+    private static PrefixTimeZonesMap $prefixTimeZonesMapForUS;
+    private static PrefixTimeZonesMap $prefixTimeZonesMapForRU;
 
     public static function setUpBeforeClass(): void
     {
@@ -52,12 +48,12 @@ class PrefixTimeZonesMapTest extends TestCase
         self::$prefixTimeZonesMapForRU = new PrefixTimeZonesMap($sortedMapForRU);
     }
 
-    public function testLookupTimeZonesForNumberCountryLevel_US()
+    public function testLookupTimeZonesForNumberCountryLevel_US(): void
     {
         $number = new PhoneNumber();
-        $number->setCountryCode(1)->setNationalNumber(1000000000);
+        $number->setCountryCode(1)->setNationalNumber('1000000000');
 
-        $this->assertEquals(
+        self::assertSame(
             [
                 self::NEW_YORK_TZ,
                 self::CHICAGO_TZ,
@@ -68,57 +64,57 @@ class PrefixTimeZonesMapTest extends TestCase
         );
     }
 
-    public function testLookupTimeZonesForNumber_ValidNumber_Chicago()
+    public function testLookupTimeZonesForNumber_ValidNumber_Chicago(): void
     {
         $number = new PhoneNumber();
-        $number->setCountryCode(1)->setNationalNumber(2051235458);
+        $number->setCountryCode(1)->setNationalNumber('2051235458');
 
-        $this->assertEquals([self::CHICAGO_TZ], self::$prefixTimeZonesMapForUS->lookupTimeZonesForNumber($number));
+        self::assertSame([self::CHICAGO_TZ], self::$prefixTimeZonesMapForUS->lookupTimeZonesForNumber($number));
     }
 
-    public function testLookupTimeZonesForNumber_LA()
+    public function testLookupTimeZonesForNumber_LA(): void
     {
         $number = new PhoneNumber();
-        $number->setCountryCode(1)->setNationalNumber(2082924565);
+        $number->setCountryCode(1)->setNationalNumber('2082924565');
 
-        $this->assertEquals([self::LOS_ANGELES_TZ], self::$prefixTimeZonesMapForUS->lookupTimeZonesForNumber($number));
+        self::assertSame([self::LOS_ANGELES_TZ], self::$prefixTimeZonesMapForUS->lookupTimeZonesForNumber($number));
     }
 
-    public function testLookupTimeZonesForNumber_NY()
+    public function testLookupTimeZonesForNumber_NY(): void
     {
         $number = new PhoneNumber();
-        $number->setCountryCode(1)->setNationalNumber(2016641234);
+        $number->setCountryCode(1)->setNationalNumber('2016641234');
 
-        $this->assertEquals([self::NEW_YORK_TZ], self::$prefixTimeZonesMapForUS->lookupTimeZonesForNumber($number));
+        self::assertSame([self::NEW_YORK_TZ], self::$prefixTimeZonesMapForUS->lookupTimeZonesForNumber($number));
     }
 
-    public function testLookupTimeZonesForNumber_CH()
+    public function testLookupTimeZonesForNumber_CH(): void
     {
         $number = new PhoneNumber();
-        $number->setCountryCode(41)->setNationalNumber(446681300);
+        $number->setCountryCode(41)->setNationalNumber('446681300');
 
-        $this->assertEquals([], self::$prefixTimeZonesMapForUS->lookupTimeZonesForNumber($number));
+        self::assertSame([], self::$prefixTimeZonesMapForUS->lookupTimeZonesForNumber($number));
     }
 
-    public function testLookupTimeZonesForNumber_RU()
+    public function testLookupTimeZonesForNumber_RU(): void
     {
         $number = new PhoneNumber();
-        $number->setCountryCode(7)->setNationalNumber(87945154);
+        $number->setCountryCode(7)->setNationalNumber('87945154');
 
-        $this->assertEquals([self::MOSCOW_TZ], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
+        self::assertSame([self::MOSCOW_TZ], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
 
-        $number->setNationalNumber(421548578);
-        $this->assertEquals([self::VLADIVOSTOK_TZ], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
+        $number->setNationalNumber('421548578');
+        self::assertSame([self::VLADIVOSTOK_TZ], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
 
-        $number->setNationalNumber(342457897);
-        $this->assertEquals([self::YEKATERINBURG_TZ], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
+        $number->setNationalNumber('342457897');
+        self::assertSame([self::YEKATERINBURG_TZ], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
 
         // A mobile number
-        $number->setNationalNumber(9342457897);
-        $this->assertEquals([], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
+        $number->setNationalNumber('9342457897');
+        self::assertSame([], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
 
         // An invalid number (too short)
-        $number->setNationalNumber(3951);
-        $this->assertEquals([self::IRKUTSK_TZ], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
+        $number->setNationalNumber('3951');
+        self::assertSame([self::IRKUTSK_TZ], self::$prefixTimeZonesMapForRU->lookupTimeZonesForNumber($number));
     }
 }
